# s3-tree  
  
uses the tree command to display the objects in an s3 bucket in a tree-like diagram.  
  
### dependencies  
  
tree  
python3  
aws cli  
  
### usage  
  
`$ s3-tree bucketname`  
  
*i tried to write this so it would work in windows. if anyone tries it lemme know.*
